#!/bin/sh -efu
#
# Copyright (C) 2008  Alexey Gladkov <gladkov.alexey@gmail.com>
#
# This file is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
#

. shell-args
. shell-error
. shell-quote

. '/usr/share/rpm-build-mozilla/mozilla-sh-functions'
p='xulrunner'

show_help() {
	cat <<-EOF
	Usage: $PROG [Options] application.ini

	Options:

	  -v, --verbose           print a message for each action;
	  -V, --version           print program version and exit;
	  -h, --help              show this text and exit.

	Report bugs to gladkov.alexey@gmail.com

EOF
	exit
}

print_version() {
	cat <<EOF
$PROG version $PROG_VERSION
Written by Alexey Gladkov <gladkov.alexey@gmail.com>

Copyright (C) 2008  Alexey Gladkov <gladkov.alexey@gmail.com>
This is free software; see the source for copying conditions.  There is NO
warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
EOF
	exit
}


TEMP=`getopt -n $PROG -o v,V,h -l verbose,version,help -- "$@"` ||
	show_usage
eval set -- "$TEMP"

while :; do
	case "$1" in
	    -v|--verbose) verbose=-v
		;;
	    -V|--version) print_version
		;;
	    -h|--help) show_help
		;;
	    --) shift; break
		;;
	    *) fatal "Unrecognized option: $1"
		;;
	esac
	shift
done

if [ "$#" -eq 0 ]; then
	fatal 'Not enough arguments.'
elif [ "$#" -gt 1 ]; then
	fatal 'Too many arguments.'
fi

application_ini="$(readlink -ev "$1")"
section_gecko=
min=
max=

while read l; do
	if [ -z "${l##*\[Gecko\]*}" ]; then
		section_gecko=1
		continue
	fi

	if [ -n "$section_gecko" ]; then
		case "$l" in
			MinVersion=*) min="${l#MinVersion=}" ;;
			MaxVersion=*) max="${l#MaxVersion=}" ;;
			*) section_gecko= ;;
		esac
	fi

	if [ -n "$max" -a -n "$min" ]; then
		show_requires
		break
	fi

done < "$application_ini"
